==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/es-MX/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Accesorio ingresado',
    'Accessory_Checkout_Notification' => 'Accesorio asignado',
    'Asset_Checkin_Notification' => 'Activo ingresado',
    'Asset_Checkout_Notification' => 'Activo asignado',
    'Confirm_Accessory_Checkin' => 'Confirmación de ingreso de accesorio',
    'Confirm_Asset_Checkin' => 'Confirmación de ingreso de activo',
    'Confirm_accessory_delivery' => 'Confirmación de entrega de accesorio',
    'Confirm_asset_delivery' => 'Confirmación de entrega de activo',
    'Confirm_consumable_delivery' => 'Confirmación de entrega de consumible',
    'Confirm_license_delivery' => 'Confirmación de entrega de licencia',
    'Consumable_checkout_notification' => 'Consumible asignado',
    'Days' => 'Días',
    'Expected_Checkin_Date' => 'Un activo asignado a Ud. debe ser devuelto el :date',
    'Expected_Checkin_Notification' => 'Recordatorio: :name se acerca la fecha de devolución',
    'Expected_Checkin_Report' => 'Informe de próximas devoluciones de activos',
    'Expiring_Assets_Report' => 'Informe de activos con garantía próxima a vencer.',
    'Expiring_Licenses_Report' => 'Informe de licencias que expiran.',
    'Item_Request_Canceled' => 'Solicitud de cancelación de requerimiento',
    'Item_Requested' => 'Artículo solicitado',
    'License_Checkin_Notification' => 'Licencia devuelta',
    'License_Checkout_Notification' => 'Licencia asignada',
    'Low_Inventory_Report' => 'Informe sobre inventario bajo',
    'a_user_canceled' => 'El usuario ha cancelado el elemento solicitado en la página web',
    'a_user_requested' => 'Un usuario ha solicitado un elemento en la página web',
    'acceptance_asset_accepted' => 'Un usuario ha aceptado un elemento',
    'acceptance_asset_declined' => 'Un usuario ha rechazado un elemento',
    'accessory_name' => 'Nombre de accesorio:',
    'additional_notes' => 'Notas adicionales:',
    'admin_has_created' => 'Un administrador ha creado una cuenta para ti en la web :web.',
    'asset' => 'Activo:',
    'asset_name' => 'Nombre del activo:',
    'asset_requested' => 'Activo solicitado',
    'asset_tag' => 'Placa del activo',
    'assets_warrantee_alert' => 'Hay :count activo con su garantía que expira en los próximos :threshold days.|Hay :count activos con garantías que expiran en los siguientes :threshold days.',
    'assigned_to' => 'Asignado a',
    'best_regards' => 'Cordialmente,',
    'canceled' => 'Cancelado:',
    'checkin_date' => 'Fecha de devolución:',
    'checkout_date' => 'Fecha de asignación:',
    'checkedout_from' => 'Asignado desde',
    'checkedin_from'  => 'Devuelto desde',
    'checked_into' => 'Devuelto en',
    'click_on_the_link_accessory' => 'Haga clic en el enlace en la parte inferior para confirmar que ha recibido el accesorio.',
    'click_on_the_link_asset' => 'Haga clic en el enlace en la parte inferior para confirmar que ha recibido el activo.',
    'click_to_confirm' => 'Por favor, pulsa en el siguiente enlace para verificar tu cuenta de :web:',
    'current_QTY' => 'Cantidad actual',
    'days' => 'Días',
    'expecting_checkin_date' => 'Fecha esperada de devolución:',
    'expires' => 'Vence',
    'hello' => 'Hola',
    'hi' => 'Hola',
    'i_have_read' => 'He leído y aceptado los términos de uso, y he recibido este artículo.',
    'inventory_report' => 'Reporte de Inventario',
    'item' => 'Elemento:',
    'item_checked_reminder' => 'Este es un recordatorio de que actualmente tiene :count elemento(s) asignado(s) que no ha aceptado o rechazado. Haga clic en el siguiente enlace para confirmar su decisión.',
    'license_expiring_alert' => 'Hay :count licencia que expira en los próximos :threshold días. | Hay :count licencias que expiran en los próximos :threshold días.',
    'link_to_update_password' => 'Haga clic en el siguiente enlace para actualizar su: contraseña de la web:',
    'login' => 'Entrar:',
    'login_first_admin' => 'Inicie sesión en su nueva instalación de Snipe-IT usando las credenciales:',
    'low_inventory_alert' => 'Hay :count elemento que está por debajo del inventario mínimo o que pronto lo estará.|Hay :count elementos que están por debajo del inventario mínimo o que pronto lo estarán.',
    'min_QTY' => 'Cantidad mínima',
    'name' => 'Nombre',
    'new_item_checked' => 'Un nuevo artículo ha sido asignado a su nombre, los detalles están a continuación.',
    'notes' => 'Notas',
    'password' => 'Contraseña:',
    'password_reset' => 'Reiniciar la contraseña',
    'read_the_terms' => 'Por favor lea los términos de uso a continuación.',
    'read_the_terms_and_click' => 'Por favor, lea los términos de uso a continuación, y haga clic en el enlace en la parte inferior para confirmar que usted lee y acepta las condiciones de uso, y han recibido el activo.',
    'requested' => 'Solicitado:',
    'reset_link' => 'Su enlace de restablecimiento de contraseña',
    'reset_password' => 'Haga Clic aquí para restablecer su contraseña:',
    'rights_reserved' => 'Todos los derechos reservados.',
    'serial' => 'Serial',
    'snipe_webhook_test' => 'Prueba de integración de Snipe-IT',
    'snipe_webhook_summary' => 'Resumen de la prueba de integración de Snipe-IT',
    'supplier' => 'Proveedor',
    'tag' => 'Placa',
    'test_email' => 'Email de prueba de Snipe-IT',
    'test_mail_text' => 'Esto es una prueba desde el sistema de gestión de activos Snipe-IT. Si recibió este mensaje, el correo está funcionando :)',
    'the_following_item' => 'El siguiente artículo ha sido devuelto: ',
    'to_reset' => 'Para restaurar tu contraseña de :web, rellena este formulario:',
    'type' => 'Tipo',
    'upcoming-audits' => 'Hay :count para ser auditado antes de :threshold días.|Hay :count activos para ser auditados antes de :threshold días.',
    'user' => 'Usuario',
    'username' => 'Nombre de usuario',
    'unaccepted_asset_reminder' => 'Tiene activos pendientes por aceptar.',
    'welcome' => 'Bienvenido, :name',
    'welcome_to' => '¡Bienvenido a: web!',
    'your_assets' => 'Ver sus activos',
    'your_credentials' => 'Sus credenciales de Snipe-IT',
    'mail_sent' => '¡Correo enviado exitosamente!.',
];

==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/es-MX/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Accesorio ingresado',
    'Accessory_Checkout_Notification' => 'Accesorio asignado',
    'Asset_Checkin_Notification' => 'Activo ingresado',
    'Asset_Checkout_Notification' => 'Activo asignado',
    'Confirm_Accessory_Checkin' => 'Confirmación de ingreso de accesorio',
    'Confirm_Asset_Checkin' => 'Confirmación de ingreso de activo',
    'Confirm_accessory_delivery' => 'Confirmación de entrega de accesorio',
    'Confirm_asset_delivery' => 'Confirmación de entrega de activo',
    'Confirm_consumable_delivery' => 'Confirmación de entrega de consumible',
    'Confirm_license_delivery' => 'Confirmación de entrega de licencia',
    'Consumable_checkout_notification' => 'Consumible asignado',
    'Days' => 'Días',
    'Expected_Checkin_Date' => 'Un activo asignado a Ud. debe ser devuelto el :date',
    'Expected_Checkin_Notification' => 'Recordatorio: :name se acerca la fecha de devolución',
    'Expected_Checkin_Report' => 'Informe de próximas devoluciones de activos',
    'Expiring_Assets_Report' => 'Informe de activos con garantía próxima a vencer.',
    'Expiring_Licenses_Report' => 'Informe de licencias que expiran.',
    'Item_Request_Canceled' => 'Solicitud de cancelación de requerimiento',
    'Item_Requested' => 'Artículo solicitado',
    'License_Checkin_Notification' => 'Licencia devuelta',
    'License_Checkout_Notification' => 'Licencia asignada',
    'Low_Inventory_Report' => 'Informe sobre inventario bajo',
    'a_user_canceled' => 'El usuario ha cancelado el elemento solicitado en la página web',
    'a_user_requested' => 'Un usuario ha solicitado un elemento en la página web',
    'acceptance_asset_accepted' => 'Un usuario ha aceptado un elemento',
    'acceptance_asset_declined' => 'Un usuario ha rechazado un elemento',
    'accessory_name' => 'Nombre de accesorio',
    'additional_notes' => 'Notas adicionales',
    'admin_has_created' => 'Un administrador ha creado una cuenta para ti en la web :web.',
    'asset' => 'Activo',
    'asset_name' => 'Nombre del activo',
    'asset_requested' => 'Activo solicitado',
    'asset_tag' => 'Placa del activo',
    'assets_warrantee_alert' => 'Hay :count activo con su garantía que expira en los próximos :threshold days.|Hay :count activos con garantías que expiran en los siguientes :threshold days.',
    'assigned_to' => 'Asignado a',
    'best_regards' => 'Cordialmente,',
    'canceled' => 'Cancelado',
    'checkin_date' => 'Fecha de ingreso',
    'checkout_date' => 'Fecha de asignación',
    'checkedout_from' => 'Asignado desde',
    'checkedin_from'  => 'Devuelto desde',
    'checked_into' => 'Devuelto en',
    'click_on_the_link_accessory' => 'Haga clic en el enlace en la parte inferior para confirmar que ha recibido el accesorio.',
    'click_on_the_link_asset' => 'Haga clic en el enlace en la parte inferior para confirmar que ha recibido el activo.',
    'click_to_confirm' => 'Por favor, haga clic en el siguiente enlace para confirmar su cuenta de :web:',
    'current_QTY' => 'Cantidad actual',
    'days' => 'Días',
    'expecting_checkin_date' => 'Fecha esperada de devolución',
    'expires' => 'Vence',
    'hello' => 'Hola',
    'hi' => 'Hola',
    'i_have_read' => 'He leído y aceptado los términos de uso, y he recibido este artículo.',
    'inventory_report' => 'Reporte de Inventario',
    'item' => 'Elemento',
    'item_checked_reminder' => 'Este es un recordatorio de que actualmente tiene :count elemento(s) asignado(s) que no ha aceptado o rechazado. Haga clic en el siguiente enlace para confirmar su decisión.',
    'license_expiring_alert' => 'Hay :count licencia que expira en los próximos :threshold días. | Hay :count licencias que expiran en los próximos :threshold días.',
    'link_to_update_password' => 'Por favor, haga clic en el siguiente enlace para actualizar contraseña de :web :',
    'login' => 'Entrar:',
    'login_first_admin' => 'Inicie sesión en su nueva instalación de Snipe-IT usando las credenciales:',
    'low_inventory_alert' => 'Hay :count elemento que está por debajo del inventario mínimo o que pronto lo estará.|Hay :count elementos que están por debajo del inventario mínimo o que pronto lo estarán.',
    'min_QTY' => 'Cantidad mínima',
    'name' => 'Nombre',
    'new_item_checked' => 'Un nuevo artículo ha sido asignado a su nombre, los detalles están a continuación.',
    'notes' => 'Notas',
    'password' => 'Contraseña',
    'password_reset' => 'Reiniciar la contraseña',
    'read_the_terms' => 'Por favor lea los términos de uso a continuación.',
    'read_the_terms_and_click' => 'Por favor, lea los términos de uso a continuación, y haga clic en el enlace en la parte inferior para confirmar que usted lee y acepta las condiciones de uso, y han recibido el activo.',
    'requested' => 'Solicitado',
    'reset_link' => 'Su enlace de restablecimiento de contraseña',
    'reset_password' => 'Haaga clic aquí para restablecer tu contraseña:',
    'rights_reserved' => 'Todos los derechos reservados.',
    'serial' => 'Serial',
    'snipe_webhook_test' => 'Prueba de integración de Snipe-IT',
    'snipe_webhook_summary' => 'Resumen de la prueba de integración de Snipe-IT',
    'supplier' => 'Proveedor',
    'tag' => 'Placa',
    'test_email' => 'Email de prueba de Snipe-IT',
    'test_mail_text' => 'Esto es una prueba desde el sistema de gestión de activos Snipe-IT. Si recibió este mensaje, el correo está funcionando :)',
    'the_following_item' => 'El siguiente artículo ha sido devuelto: ',
    'to_reset' => 'Para restaurar tu contraseña de :web, diligencie este formulario:',
    'type' => 'Tipo',
    'upcoming-audits' => 'Hay :count para ser auditado antes de :threshold días.|Hay :count activos para ser auditados antes de :threshold días.',
    'user' => 'Usuario',
    'username' => 'Nombre de usuario',
    'unaccepted_asset_reminder' => 'Tiene activos pendientes por aceptar.',
    'welcome' => 'Bienvenido, :name',
    'welcome_to' => '¡Bienvenido a: web!',
    'your_assets' => 'Ver sus activos',
    'your_credentials' => 'Sus credenciales de Snipe-IT',
    'mail_sent' => '¡Correo enviado exitosamente!.',
];
